@@ -8,6 +8,7 @@ from urllib.request import urlopen
 from urllib.parse import urlencode
 from contextlib import closing
 from datetime import datetime
+from io import StringIO
 import datetime as dt
 import pandas as pd
 import numpy as np
@@ -20,7 +21,7 @@ import json
 import zlib
 import os
 
-VERSION = 2.6
+VERSION = 2.8
 
 def dameRespuestaLlamado(url, data):
 	respuesta = ''
@@ -182,7 +183,6 @@ def timeBlend(token, anchor_ts, blend_source,
               blend_type = 'closest_observation',
               direction = 'time_prior',
               interval_output = 'count',
-              ts_restriction = None,
               oblender = None,
               interval_size = 3600,
               consumption_confirmation = 'off',
@@ -199,7 +199,7 @@ def timeBlend(token, anchor_ts, blend_source,
 		except:
 			1 * 1
 			#print('excepcion')
-		anchor_ts.sort()
+		#anchor_ts.sort()
         
 		json_parametros = {
            'token' : token,
@@ -208,7 +208,6 @@ def timeBlend(token, anchor_ts, blend_source,
            'blend_type' : blend_type,
            'direction' : direction,
            'agg_output' : interval_output,
-           'ts_restriction' : ts_restriction,
            'agg_interval_size' : interval_size,
            'missing_values' : missing_values,
         }
@@ -241,16 +240,16 @@ def timeBlend(token, anchor_ts, blend_source,
 					print(str(progress * 100) + '%')
 					time.sleep(2)
 					if resp_vacio:
-						df_resp = pd.read_json(json.dumps(respuesta['df_resp']), convert_dates=False,convert_axes=False).sort_values(['timestamp']).reset_index(drop=True)
+						df_resp = pd.read_json(StringIO(json.dumps(respuesta['df_resp'])), convert_dates=False,convert_axes=False)
 						resp_vacio = False
 					else:
-						df_resp = pd.concat([df_resp, pd.read_json(json.dumps(respuesta['df_resp']), convert_dates=False,convert_axes=False).sort_values(['timestamp']).reset_index(drop=True)], ignore_index=True)
+						df_resp = pd.concat([df_resp, pd.read_json(StringIO(json.dumps(respuesta['df_resp'])), convert_dates=False,convert_axes=False)], ignore_index=True)
 				else:
 					print(respuesta)
 			if data_format == 'dataframe':
-				return df_resp.sort_values(['timestamp']).reset_index(drop=True)
+				return df_resp
 			else:
-				return df_resp.sort_values(['timestamp']).reset_index(drop=True).to_json()
+				return df_resp.to_json()
 		else:
 			print("")
 			print("Task cancelled. To execute tasks without prompt set 'consumption_confirmation' to 'off'.")
@@ -344,16 +343,16 @@ def locationBlend(token, anchor_lat, anchor_lon, blend_source,
 					print(str(progress * 100) + '%')
 					time.sleep(2)
 					if resp_vacio:
-						df_resp = pd.read_json(json.dumps(respuesta['df_resp']), convert_dates=False,convert_axes=False).sort_values(['latitude']).reset_index(drop=True)
+						df_resp = pd.read_json(StringIO(json.dumps(respuesta['df_resp'])), convert_dates=False,convert_axes=False)
 						resp_vacio = False
 					else:
-						df_resp = pd.concat([df_resp, pd.read_json(json.dumps(respuesta['df_resp']), convert_dates=False,convert_axes=False).sort_values(['latitude']).reset_index(drop=True)], ignore_index=True)
+						df_resp = pd.concat([df_resp, pd.read_json(StringIO(json.dumps(respuesta['df_resp'])), convert_dates=False,convert_axes=False)], ignore_index=True)
 				else:
 					print(respuesta)
 			if data_format == 'dataframe':
-				return df_resp.sort_values(['latitude']).reset_index(drop=True)
+				return df_resp
 			else:
-				return df_resp.sort_values(['latitude']).reset_index(drop=True).to_json()
+				return df_resp.to_json()
 		else:
 			print("")
 			print("Task cancelled. To execute tasks without prompt set 'consumption_confirmation' to 'off'.")
@@ -631,7 +630,7 @@ def comprobarJSONaDF(df_json):
 	valido = True
 	msj = "Sucess"
 	try:
-		df_nuevo = pd.read_json(df_json, convert_dates=False, convert_axes=False)
+		df_nuevo = pd.read_json(StringIO(df_json), convert_dates=False, convert_axes=False)
 	except Exception as e:
 		df_nuevo = None
 		valido = False
